# Generated from ./Sparql.g4 by ANTLR 4.9.3
from antlr4 import *
if __name__ is not None and "." in __name__:
    from .SparqlParser import SparqlParser
else:
    from SparqlParser import SparqlParser

# This class defines a complete listener for a parse tree produced by SparqlParser.
class SparqlListener(ParseTreeListener):

    # Enter a parse tree produced by SparqlParser#query.
    def enterQuery(self, ctx:SparqlParser.QueryContext):
        pass

    # Exit a parse tree produced by SparqlParser#query.
    def exitQuery(self, ctx:SparqlParser.QueryContext):
        pass


    # Enter a parse tree produced by SparqlParser#prologue.
    def enterPrologue(self, ctx:SparqlParser.PrologueContext):
        pass

    # Exit a parse tree produced by SparqlParser#prologue.
    def exitPrologue(self, ctx:SparqlParser.PrologueContext):
        pass


    # Enter a parse tree produced by SparqlParser#baseDecl.
    def enterBaseDecl(self, ctx:SparqlParser.BaseDeclContext):
        pass

    # Exit a parse tree produced by SparqlParser#baseDecl.
    def exitBaseDecl(self, ctx:SparqlParser.BaseDeclContext):
        pass


    # Enter a parse tree produced by SparqlParser#prefixDecl.
    def enterPrefixDecl(self, ctx:SparqlParser.PrefixDeclContext):
        pass

    # Exit a parse tree produced by SparqlParser#prefixDecl.
    def exitPrefixDecl(self, ctx:SparqlParser.PrefixDeclContext):
        pass


    # Enter a parse tree produced by SparqlParser#selectQuery.
    def enterSelectQuery(self, ctx:SparqlParser.SelectQueryContext):
        pass

    # Exit a parse tree produced by SparqlParser#selectQuery.
    def exitSelectQuery(self, ctx:SparqlParser.SelectQueryContext):
        pass


    # Enter a parse tree produced by SparqlParser#subSelect.
    def enterSubSelect(self, ctx:SparqlParser.SubSelectContext):
        pass

    # Exit a parse tree produced by SparqlParser#subSelect.
    def exitSubSelect(self, ctx:SparqlParser.SubSelectContext):
        pass


    # Enter a parse tree produced by SparqlParser#selectClause.
    def enterSelectClause(self, ctx:SparqlParser.SelectClauseContext):
        pass

    # Exit a parse tree produced by SparqlParser#selectClause.
    def exitSelectClause(self, ctx:SparqlParser.SelectClauseContext):
        pass


    # Enter a parse tree produced by SparqlParser#selectModifier.
    def enterSelectModifier(self, ctx:SparqlParser.SelectModifierContext):
        pass

    # Exit a parse tree produced by SparqlParser#selectModifier.
    def exitSelectModifier(self, ctx:SparqlParser.SelectModifierContext):
        pass


    # Enter a parse tree produced by SparqlParser#selectVariables.
    def enterSelectVariables(self, ctx:SparqlParser.SelectVariablesContext):
        pass

    # Exit a parse tree produced by SparqlParser#selectVariables.
    def exitSelectVariables(self, ctx:SparqlParser.SelectVariablesContext):
        pass


    # Enter a parse tree produced by SparqlParser#constructQuery.
    def enterConstructQuery(self, ctx:SparqlParser.ConstructQueryContext):
        pass

    # Exit a parse tree produced by SparqlParser#constructQuery.
    def exitConstructQuery(self, ctx:SparqlParser.ConstructQueryContext):
        pass


    # Enter a parse tree produced by SparqlParser#describeQuery.
    def enterDescribeQuery(self, ctx:SparqlParser.DescribeQueryContext):
        pass

    # Exit a parse tree produced by SparqlParser#describeQuery.
    def exitDescribeQuery(self, ctx:SparqlParser.DescribeQueryContext):
        pass


    # Enter a parse tree produced by SparqlParser#askQuery.
    def enterAskQuery(self, ctx:SparqlParser.AskQueryContext):
        pass

    # Exit a parse tree produced by SparqlParser#askQuery.
    def exitAskQuery(self, ctx:SparqlParser.AskQueryContext):
        pass


    # Enter a parse tree produced by SparqlParser#datasetClause.
    def enterDatasetClause(self, ctx:SparqlParser.DatasetClauseContext):
        pass

    # Exit a parse tree produced by SparqlParser#datasetClause.
    def exitDatasetClause(self, ctx:SparqlParser.DatasetClauseContext):
        pass


    # Enter a parse tree produced by SparqlParser#whereClause.
    def enterWhereClause(self, ctx:SparqlParser.WhereClauseContext):
        pass

    # Exit a parse tree produced by SparqlParser#whereClause.
    def exitWhereClause(self, ctx:SparqlParser.WhereClauseContext):
        pass


    # Enter a parse tree produced by SparqlParser#solutionModifier.
    def enterSolutionModifier(self, ctx:SparqlParser.SolutionModifierContext):
        pass

    # Exit a parse tree produced by SparqlParser#solutionModifier.
    def exitSolutionModifier(self, ctx:SparqlParser.SolutionModifierContext):
        pass


    # Enter a parse tree produced by SparqlParser#groupClause.
    def enterGroupClause(self, ctx:SparqlParser.GroupClauseContext):
        pass

    # Exit a parse tree produced by SparqlParser#groupClause.
    def exitGroupClause(self, ctx:SparqlParser.GroupClauseContext):
        pass


    # Enter a parse tree produced by SparqlParser#groupCondition.
    def enterGroupCondition(self, ctx:SparqlParser.GroupConditionContext):
        pass

    # Exit a parse tree produced by SparqlParser#groupCondition.
    def exitGroupCondition(self, ctx:SparqlParser.GroupConditionContext):
        pass


    # Enter a parse tree produced by SparqlParser#havingClause.
    def enterHavingClause(self, ctx:SparqlParser.HavingClauseContext):
        pass

    # Exit a parse tree produced by SparqlParser#havingClause.
    def exitHavingClause(self, ctx:SparqlParser.HavingClauseContext):
        pass


    # Enter a parse tree produced by SparqlParser#havingCondition.
    def enterHavingCondition(self, ctx:SparqlParser.HavingConditionContext):
        pass

    # Exit a parse tree produced by SparqlParser#havingCondition.
    def exitHavingCondition(self, ctx:SparqlParser.HavingConditionContext):
        pass


    # Enter a parse tree produced by SparqlParser#orderClause.
    def enterOrderClause(self, ctx:SparqlParser.OrderClauseContext):
        pass

    # Exit a parse tree produced by SparqlParser#orderClause.
    def exitOrderClause(self, ctx:SparqlParser.OrderClauseContext):
        pass


    # Enter a parse tree produced by SparqlParser#orderCondition.
    def enterOrderCondition(self, ctx:SparqlParser.OrderConditionContext):
        pass

    # Exit a parse tree produced by SparqlParser#orderCondition.
    def exitOrderCondition(self, ctx:SparqlParser.OrderConditionContext):
        pass


    # Enter a parse tree produced by SparqlParser#limitOffsetClauses.
    def enterLimitOffsetClauses(self, ctx:SparqlParser.LimitOffsetClausesContext):
        pass

    # Exit a parse tree produced by SparqlParser#limitOffsetClauses.
    def exitLimitOffsetClauses(self, ctx:SparqlParser.LimitOffsetClausesContext):
        pass


    # Enter a parse tree produced by SparqlParser#limitClause.
    def enterLimitClause(self, ctx:SparqlParser.LimitClauseContext):
        pass

    # Exit a parse tree produced by SparqlParser#limitClause.
    def exitLimitClause(self, ctx:SparqlParser.LimitClauseContext):
        pass


    # Enter a parse tree produced by SparqlParser#offsetClause.
    def enterOffsetClause(self, ctx:SparqlParser.OffsetClauseContext):
        pass

    # Exit a parse tree produced by SparqlParser#offsetClause.
    def exitOffsetClause(self, ctx:SparqlParser.OffsetClauseContext):
        pass


    # Enter a parse tree produced by SparqlParser#valuesClause.
    def enterValuesClause(self, ctx:SparqlParser.ValuesClauseContext):
        pass

    # Exit a parse tree produced by SparqlParser#valuesClause.
    def exitValuesClause(self, ctx:SparqlParser.ValuesClauseContext):
        pass


    # Enter a parse tree produced by SparqlParser#updateCommand.
    def enterUpdateCommand(self, ctx:SparqlParser.UpdateCommandContext):
        pass

    # Exit a parse tree produced by SparqlParser#updateCommand.
    def exitUpdateCommand(self, ctx:SparqlParser.UpdateCommandContext):
        pass


    # Enter a parse tree produced by SparqlParser#update.
    def enterUpdate(self, ctx:SparqlParser.UpdateContext):
        pass

    # Exit a parse tree produced by SparqlParser#update.
    def exitUpdate(self, ctx:SparqlParser.UpdateContext):
        pass


    # Enter a parse tree produced by SparqlParser#load.
    def enterLoad(self, ctx:SparqlParser.LoadContext):
        pass

    # Exit a parse tree produced by SparqlParser#load.
    def exitLoad(self, ctx:SparqlParser.LoadContext):
        pass


    # Enter a parse tree produced by SparqlParser#clear.
    def enterClear(self, ctx:SparqlParser.ClearContext):
        pass

    # Exit a parse tree produced by SparqlParser#clear.
    def exitClear(self, ctx:SparqlParser.ClearContext):
        pass


    # Enter a parse tree produced by SparqlParser#drop.
    def enterDrop(self, ctx:SparqlParser.DropContext):
        pass

    # Exit a parse tree produced by SparqlParser#drop.
    def exitDrop(self, ctx:SparqlParser.DropContext):
        pass


    # Enter a parse tree produced by SparqlParser#create.
    def enterCreate(self, ctx:SparqlParser.CreateContext):
        pass

    # Exit a parse tree produced by SparqlParser#create.
    def exitCreate(self, ctx:SparqlParser.CreateContext):
        pass


    # Enter a parse tree produced by SparqlParser#add.
    def enterAdd(self, ctx:SparqlParser.AddContext):
        pass

    # Exit a parse tree produced by SparqlParser#add.
    def exitAdd(self, ctx:SparqlParser.AddContext):
        pass


    # Enter a parse tree produced by SparqlParser#move.
    def enterMove(self, ctx:SparqlParser.MoveContext):
        pass

    # Exit a parse tree produced by SparqlParser#move.
    def exitMove(self, ctx:SparqlParser.MoveContext):
        pass


    # Enter a parse tree produced by SparqlParser#copy.
    def enterCopy(self, ctx:SparqlParser.CopyContext):
        pass

    # Exit a parse tree produced by SparqlParser#copy.
    def exitCopy(self, ctx:SparqlParser.CopyContext):
        pass


    # Enter a parse tree produced by SparqlParser#insertData.
    def enterInsertData(self, ctx:SparqlParser.InsertDataContext):
        pass

    # Exit a parse tree produced by SparqlParser#insertData.
    def exitInsertData(self, ctx:SparqlParser.InsertDataContext):
        pass


    # Enter a parse tree produced by SparqlParser#deleteData.
    def enterDeleteData(self, ctx:SparqlParser.DeleteDataContext):
        pass

    # Exit a parse tree produced by SparqlParser#deleteData.
    def exitDeleteData(self, ctx:SparqlParser.DeleteDataContext):
        pass


    # Enter a parse tree produced by SparqlParser#deleteWhere.
    def enterDeleteWhere(self, ctx:SparqlParser.DeleteWhereContext):
        pass

    # Exit a parse tree produced by SparqlParser#deleteWhere.
    def exitDeleteWhere(self, ctx:SparqlParser.DeleteWhereContext):
        pass


    # Enter a parse tree produced by SparqlParser#modify.
    def enterModify(self, ctx:SparqlParser.ModifyContext):
        pass

    # Exit a parse tree produced by SparqlParser#modify.
    def exitModify(self, ctx:SparqlParser.ModifyContext):
        pass


    # Enter a parse tree produced by SparqlParser#deleteClause.
    def enterDeleteClause(self, ctx:SparqlParser.DeleteClauseContext):
        pass

    # Exit a parse tree produced by SparqlParser#deleteClause.
    def exitDeleteClause(self, ctx:SparqlParser.DeleteClauseContext):
        pass


    # Enter a parse tree produced by SparqlParser#insertClause.
    def enterInsertClause(self, ctx:SparqlParser.InsertClauseContext):
        pass

    # Exit a parse tree produced by SparqlParser#insertClause.
    def exitInsertClause(self, ctx:SparqlParser.InsertClauseContext):
        pass


    # Enter a parse tree produced by SparqlParser#usingClause.
    def enterUsingClause(self, ctx:SparqlParser.UsingClauseContext):
        pass

    # Exit a parse tree produced by SparqlParser#usingClause.
    def exitUsingClause(self, ctx:SparqlParser.UsingClauseContext):
        pass


    # Enter a parse tree produced by SparqlParser#graphOrDefault.
    def enterGraphOrDefault(self, ctx:SparqlParser.GraphOrDefaultContext):
        pass

    # Exit a parse tree produced by SparqlParser#graphOrDefault.
    def exitGraphOrDefault(self, ctx:SparqlParser.GraphOrDefaultContext):
        pass


    # Enter a parse tree produced by SparqlParser#graphRef.
    def enterGraphRef(self, ctx:SparqlParser.GraphRefContext):
        pass

    # Exit a parse tree produced by SparqlParser#graphRef.
    def exitGraphRef(self, ctx:SparqlParser.GraphRefContext):
        pass


    # Enter a parse tree produced by SparqlParser#graphRefAll.
    def enterGraphRefAll(self, ctx:SparqlParser.GraphRefAllContext):
        pass

    # Exit a parse tree produced by SparqlParser#graphRefAll.
    def exitGraphRefAll(self, ctx:SparqlParser.GraphRefAllContext):
        pass


    # Enter a parse tree produced by SparqlParser#quadPattern.
    def enterQuadPattern(self, ctx:SparqlParser.QuadPatternContext):
        pass

    # Exit a parse tree produced by SparqlParser#quadPattern.
    def exitQuadPattern(self, ctx:SparqlParser.QuadPatternContext):
        pass


    # Enter a parse tree produced by SparqlParser#quadData.
    def enterQuadData(self, ctx:SparqlParser.QuadDataContext):
        pass

    # Exit a parse tree produced by SparqlParser#quadData.
    def exitQuadData(self, ctx:SparqlParser.QuadDataContext):
        pass


    # Enter a parse tree produced by SparqlParser#quads.
    def enterQuads(self, ctx:SparqlParser.QuadsContext):
        pass

    # Exit a parse tree produced by SparqlParser#quads.
    def exitQuads(self, ctx:SparqlParser.QuadsContext):
        pass


    # Enter a parse tree produced by SparqlParser#quadsDetails.
    def enterQuadsDetails(self, ctx:SparqlParser.QuadsDetailsContext):
        pass

    # Exit a parse tree produced by SparqlParser#quadsDetails.
    def exitQuadsDetails(self, ctx:SparqlParser.QuadsDetailsContext):
        pass


    # Enter a parse tree produced by SparqlParser#quadsNotTriples.
    def enterQuadsNotTriples(self, ctx:SparqlParser.QuadsNotTriplesContext):
        pass

    # Exit a parse tree produced by SparqlParser#quadsNotTriples.
    def exitQuadsNotTriples(self, ctx:SparqlParser.QuadsNotTriplesContext):
        pass


    # Enter a parse tree produced by SparqlParser#triplesTemplate.
    def enterTriplesTemplate(self, ctx:SparqlParser.TriplesTemplateContext):
        pass

    # Exit a parse tree produced by SparqlParser#triplesTemplate.
    def exitTriplesTemplate(self, ctx:SparqlParser.TriplesTemplateContext):
        pass


    # Enter a parse tree produced by SparqlParser#groupGraphPattern.
    def enterGroupGraphPattern(self, ctx:SparqlParser.GroupGraphPatternContext):
        pass

    # Exit a parse tree produced by SparqlParser#groupGraphPattern.
    def exitGroupGraphPattern(self, ctx:SparqlParser.GroupGraphPatternContext):
        pass


    # Enter a parse tree produced by SparqlParser#groupGraphPatternSub.
    def enterGroupGraphPatternSub(self, ctx:SparqlParser.GroupGraphPatternSubContext):
        pass

    # Exit a parse tree produced by SparqlParser#groupGraphPatternSub.
    def exitGroupGraphPatternSub(self, ctx:SparqlParser.GroupGraphPatternSubContext):
        pass


    # Enter a parse tree produced by SparqlParser#groupGraphPatternSubList.
    def enterGroupGraphPatternSubList(self, ctx:SparqlParser.GroupGraphPatternSubListContext):
        pass

    # Exit a parse tree produced by SparqlParser#groupGraphPatternSubList.
    def exitGroupGraphPatternSubList(self, ctx:SparqlParser.GroupGraphPatternSubListContext):
        pass


    # Enter a parse tree produced by SparqlParser#triplesBlock.
    def enterTriplesBlock(self, ctx:SparqlParser.TriplesBlockContext):
        pass

    # Exit a parse tree produced by SparqlParser#triplesBlock.
    def exitTriplesBlock(self, ctx:SparqlParser.TriplesBlockContext):
        pass


    # Enter a parse tree produced by SparqlParser#graphPatternNotTriples.
    def enterGraphPatternNotTriples(self, ctx:SparqlParser.GraphPatternNotTriplesContext):
        pass

    # Exit a parse tree produced by SparqlParser#graphPatternNotTriples.
    def exitGraphPatternNotTriples(self, ctx:SparqlParser.GraphPatternNotTriplesContext):
        pass


    # Enter a parse tree produced by SparqlParser#optionalGraphPattern.
    def enterOptionalGraphPattern(self, ctx:SparqlParser.OptionalGraphPatternContext):
        pass

    # Exit a parse tree produced by SparqlParser#optionalGraphPattern.
    def exitOptionalGraphPattern(self, ctx:SparqlParser.OptionalGraphPatternContext):
        pass


    # Enter a parse tree produced by SparqlParser#graphGraphPattern.
    def enterGraphGraphPattern(self, ctx:SparqlParser.GraphGraphPatternContext):
        pass

    # Exit a parse tree produced by SparqlParser#graphGraphPattern.
    def exitGraphGraphPattern(self, ctx:SparqlParser.GraphGraphPatternContext):
        pass


    # Enter a parse tree produced by SparqlParser#serviceGraphPattern.
    def enterServiceGraphPattern(self, ctx:SparqlParser.ServiceGraphPatternContext):
        pass

    # Exit a parse tree produced by SparqlParser#serviceGraphPattern.
    def exitServiceGraphPattern(self, ctx:SparqlParser.ServiceGraphPatternContext):
        pass


    # Enter a parse tree produced by SparqlParser#bind.
    def enterBind(self, ctx:SparqlParser.BindContext):
        pass

    # Exit a parse tree produced by SparqlParser#bind.
    def exitBind(self, ctx:SparqlParser.BindContext):
        pass


    # Enter a parse tree produced by SparqlParser#inlineData.
    def enterInlineData(self, ctx:SparqlParser.InlineDataContext):
        pass

    # Exit a parse tree produced by SparqlParser#inlineData.
    def exitInlineData(self, ctx:SparqlParser.InlineDataContext):
        pass


    # Enter a parse tree produced by SparqlParser#dataBlock.
    def enterDataBlock(self, ctx:SparqlParser.DataBlockContext):
        pass

    # Exit a parse tree produced by SparqlParser#dataBlock.
    def exitDataBlock(self, ctx:SparqlParser.DataBlockContext):
        pass


    # Enter a parse tree produced by SparqlParser#inlineDataOneVar.
    def enterInlineDataOneVar(self, ctx:SparqlParser.InlineDataOneVarContext):
        pass

    # Exit a parse tree produced by SparqlParser#inlineDataOneVar.
    def exitInlineDataOneVar(self, ctx:SparqlParser.InlineDataOneVarContext):
        pass


    # Enter a parse tree produced by SparqlParser#inlineDataFull.
    def enterInlineDataFull(self, ctx:SparqlParser.InlineDataFullContext):
        pass

    # Exit a parse tree produced by SparqlParser#inlineDataFull.
    def exitInlineDataFull(self, ctx:SparqlParser.InlineDataFullContext):
        pass


    # Enter a parse tree produced by SparqlParser#dataBlockValues.
    def enterDataBlockValues(self, ctx:SparqlParser.DataBlockValuesContext):
        pass

    # Exit a parse tree produced by SparqlParser#dataBlockValues.
    def exitDataBlockValues(self, ctx:SparqlParser.DataBlockValuesContext):
        pass


    # Enter a parse tree produced by SparqlParser#dataBlockValue.
    def enterDataBlockValue(self, ctx:SparqlParser.DataBlockValueContext):
        pass

    # Exit a parse tree produced by SparqlParser#dataBlockValue.
    def exitDataBlockValue(self, ctx:SparqlParser.DataBlockValueContext):
        pass


    # Enter a parse tree produced by SparqlParser#minusGraphPattern.
    def enterMinusGraphPattern(self, ctx:SparqlParser.MinusGraphPatternContext):
        pass

    # Exit a parse tree produced by SparqlParser#minusGraphPattern.
    def exitMinusGraphPattern(self, ctx:SparqlParser.MinusGraphPatternContext):
        pass


    # Enter a parse tree produced by SparqlParser#groupOrUnionGraphPattern.
    def enterGroupOrUnionGraphPattern(self, ctx:SparqlParser.GroupOrUnionGraphPatternContext):
        pass

    # Exit a parse tree produced by SparqlParser#groupOrUnionGraphPattern.
    def exitGroupOrUnionGraphPattern(self, ctx:SparqlParser.GroupOrUnionGraphPatternContext):
        pass


    # Enter a parse tree produced by SparqlParser#filter.
    def enterFilter(self, ctx:SparqlParser.FilterContext):
        pass

    # Exit a parse tree produced by SparqlParser#filter.
    def exitFilter(self, ctx:SparqlParser.FilterContext):
        pass


    # Enter a parse tree produced by SparqlParser#constraint.
    def enterConstraint(self, ctx:SparqlParser.ConstraintContext):
        pass

    # Exit a parse tree produced by SparqlParser#constraint.
    def exitConstraint(self, ctx:SparqlParser.ConstraintContext):
        pass


    # Enter a parse tree produced by SparqlParser#functionCall.
    def enterFunctionCall(self, ctx:SparqlParser.FunctionCallContext):
        pass

    # Exit a parse tree produced by SparqlParser#functionCall.
    def exitFunctionCall(self, ctx:SparqlParser.FunctionCallContext):
        pass


    # Enter a parse tree produced by SparqlParser#argList.
    def enterArgList(self, ctx:SparqlParser.ArgListContext):
        pass

    # Exit a parse tree produced by SparqlParser#argList.
    def exitArgList(self, ctx:SparqlParser.ArgListContext):
        pass


    # Enter a parse tree produced by SparqlParser#expressionList.
    def enterExpressionList(self, ctx:SparqlParser.ExpressionListContext):
        pass

    # Exit a parse tree produced by SparqlParser#expressionList.
    def exitExpressionList(self, ctx:SparqlParser.ExpressionListContext):
        pass


    # Enter a parse tree produced by SparqlParser#constructTemplate.
    def enterConstructTemplate(self, ctx:SparqlParser.ConstructTemplateContext):
        pass

    # Exit a parse tree produced by SparqlParser#constructTemplate.
    def exitConstructTemplate(self, ctx:SparqlParser.ConstructTemplateContext):
        pass


    # Enter a parse tree produced by SparqlParser#constructTriples.
    def enterConstructTriples(self, ctx:SparqlParser.ConstructTriplesContext):
        pass

    # Exit a parse tree produced by SparqlParser#constructTriples.
    def exitConstructTriples(self, ctx:SparqlParser.ConstructTriplesContext):
        pass


    # Enter a parse tree produced by SparqlParser#triplesSameSubject.
    def enterTriplesSameSubject(self, ctx:SparqlParser.TriplesSameSubjectContext):
        pass

    # Exit a parse tree produced by SparqlParser#triplesSameSubject.
    def exitTriplesSameSubject(self, ctx:SparqlParser.TriplesSameSubjectContext):
        pass


    # Enter a parse tree produced by SparqlParser#propertyList.
    def enterPropertyList(self, ctx:SparqlParser.PropertyListContext):
        pass

    # Exit a parse tree produced by SparqlParser#propertyList.
    def exitPropertyList(self, ctx:SparqlParser.PropertyListContext):
        pass


    # Enter a parse tree produced by SparqlParser#propertyListNotEmpty.
    def enterPropertyListNotEmpty(self, ctx:SparqlParser.PropertyListNotEmptyContext):
        pass

    # Exit a parse tree produced by SparqlParser#propertyListNotEmpty.
    def exitPropertyListNotEmpty(self, ctx:SparqlParser.PropertyListNotEmptyContext):
        pass


    # Enter a parse tree produced by SparqlParser#verb.
    def enterVerb(self, ctx:SparqlParser.VerbContext):
        pass

    # Exit a parse tree produced by SparqlParser#verb.
    def exitVerb(self, ctx:SparqlParser.VerbContext):
        pass


    # Enter a parse tree produced by SparqlParser#objectList.
    def enterObjectList(self, ctx:SparqlParser.ObjectListContext):
        pass

    # Exit a parse tree produced by SparqlParser#objectList.
    def exitObjectList(self, ctx:SparqlParser.ObjectListContext):
        pass


    # Enter a parse tree produced by SparqlParser#object.
    def enterObject(self, ctx:SparqlParser.ObjectContext):
        pass

    # Exit a parse tree produced by SparqlParser#object.
    def exitObject(self, ctx:SparqlParser.ObjectContext):
        pass


    # Enter a parse tree produced by SparqlParser#triplesSameSubjectPath.
    def enterTriplesSameSubjectPath(self, ctx:SparqlParser.TriplesSameSubjectPathContext):
        pass

    # Exit a parse tree produced by SparqlParser#triplesSameSubjectPath.
    def exitTriplesSameSubjectPath(self, ctx:SparqlParser.TriplesSameSubjectPathContext):
        pass


    # Enter a parse tree produced by SparqlParser#propertyListPath.
    def enterPropertyListPath(self, ctx:SparqlParser.PropertyListPathContext):
        pass

    # Exit a parse tree produced by SparqlParser#propertyListPath.
    def exitPropertyListPath(self, ctx:SparqlParser.PropertyListPathContext):
        pass


    # Enter a parse tree produced by SparqlParser#propertyListPathNotEmpty.
    def enterPropertyListPathNotEmpty(self, ctx:SparqlParser.PropertyListPathNotEmptyContext):
        pass

    # Exit a parse tree produced by SparqlParser#propertyListPathNotEmpty.
    def exitPropertyListPathNotEmpty(self, ctx:SparqlParser.PropertyListPathNotEmptyContext):
        pass


    # Enter a parse tree produced by SparqlParser#propertyListPathNotEmptyList.
    def enterPropertyListPathNotEmptyList(self, ctx:SparqlParser.PropertyListPathNotEmptyListContext):
        pass

    # Exit a parse tree produced by SparqlParser#propertyListPathNotEmptyList.
    def exitPropertyListPathNotEmptyList(self, ctx:SparqlParser.PropertyListPathNotEmptyListContext):
        pass


    # Enter a parse tree produced by SparqlParser#verbPath.
    def enterVerbPath(self, ctx:SparqlParser.VerbPathContext):
        pass

    # Exit a parse tree produced by SparqlParser#verbPath.
    def exitVerbPath(self, ctx:SparqlParser.VerbPathContext):
        pass


    # Enter a parse tree produced by SparqlParser#verbSimple.
    def enterVerbSimple(self, ctx:SparqlParser.VerbSimpleContext):
        pass

    # Exit a parse tree produced by SparqlParser#verbSimple.
    def exitVerbSimple(self, ctx:SparqlParser.VerbSimpleContext):
        pass


    # Enter a parse tree produced by SparqlParser#objectListPath.
    def enterObjectListPath(self, ctx:SparqlParser.ObjectListPathContext):
        pass

    # Exit a parse tree produced by SparqlParser#objectListPath.
    def exitObjectListPath(self, ctx:SparqlParser.ObjectListPathContext):
        pass


    # Enter a parse tree produced by SparqlParser#objectPath.
    def enterObjectPath(self, ctx:SparqlParser.ObjectPathContext):
        pass

    # Exit a parse tree produced by SparqlParser#objectPath.
    def exitObjectPath(self, ctx:SparqlParser.ObjectPathContext):
        pass


    # Enter a parse tree produced by SparqlParser#path.
    def enterPath(self, ctx:SparqlParser.PathContext):
        pass

    # Exit a parse tree produced by SparqlParser#path.
    def exitPath(self, ctx:SparqlParser.PathContext):
        pass


    # Enter a parse tree produced by SparqlParser#pathAlternative.
    def enterPathAlternative(self, ctx:SparqlParser.PathAlternativeContext):
        pass

    # Exit a parse tree produced by SparqlParser#pathAlternative.
    def exitPathAlternative(self, ctx:SparqlParser.PathAlternativeContext):
        pass


    # Enter a parse tree produced by SparqlParser#pathSequence.
    def enterPathSequence(self, ctx:SparqlParser.PathSequenceContext):
        pass

    # Exit a parse tree produced by SparqlParser#pathSequence.
    def exitPathSequence(self, ctx:SparqlParser.PathSequenceContext):
        pass


    # Enter a parse tree produced by SparqlParser#pathElt.
    def enterPathElt(self, ctx:SparqlParser.PathEltContext):
        pass

    # Exit a parse tree produced by SparqlParser#pathElt.
    def exitPathElt(self, ctx:SparqlParser.PathEltContext):
        pass


    # Enter a parse tree produced by SparqlParser#pathEltOrInverse.
    def enterPathEltOrInverse(self, ctx:SparqlParser.PathEltOrInverseContext):
        pass

    # Exit a parse tree produced by SparqlParser#pathEltOrInverse.
    def exitPathEltOrInverse(self, ctx:SparqlParser.PathEltOrInverseContext):
        pass


    # Enter a parse tree produced by SparqlParser#pathMod.
    def enterPathMod(self, ctx:SparqlParser.PathModContext):
        pass

    # Exit a parse tree produced by SparqlParser#pathMod.
    def exitPathMod(self, ctx:SparqlParser.PathModContext):
        pass


    # Enter a parse tree produced by SparqlParser#pathPrimary.
    def enterPathPrimary(self, ctx:SparqlParser.PathPrimaryContext):
        pass

    # Exit a parse tree produced by SparqlParser#pathPrimary.
    def exitPathPrimary(self, ctx:SparqlParser.PathPrimaryContext):
        pass


    # Enter a parse tree produced by SparqlParser#pathNegatedPropertySet.
    def enterPathNegatedPropertySet(self, ctx:SparqlParser.PathNegatedPropertySetContext):
        pass

    # Exit a parse tree produced by SparqlParser#pathNegatedPropertySet.
    def exitPathNegatedPropertySet(self, ctx:SparqlParser.PathNegatedPropertySetContext):
        pass


    # Enter a parse tree produced by SparqlParser#pathOneInPropertySet.
    def enterPathOneInPropertySet(self, ctx:SparqlParser.PathOneInPropertySetContext):
        pass

    # Exit a parse tree produced by SparqlParser#pathOneInPropertySet.
    def exitPathOneInPropertySet(self, ctx:SparqlParser.PathOneInPropertySetContext):
        pass


    # Enter a parse tree produced by SparqlParser#integer.
    def enterInteger(self, ctx:SparqlParser.IntegerContext):
        pass

    # Exit a parse tree produced by SparqlParser#integer.
    def exitInteger(self, ctx:SparqlParser.IntegerContext):
        pass


    # Enter a parse tree produced by SparqlParser#triplesNode.
    def enterTriplesNode(self, ctx:SparqlParser.TriplesNodeContext):
        pass

    # Exit a parse tree produced by SparqlParser#triplesNode.
    def exitTriplesNode(self, ctx:SparqlParser.TriplesNodeContext):
        pass


    # Enter a parse tree produced by SparqlParser#blankNodePropertyList.
    def enterBlankNodePropertyList(self, ctx:SparqlParser.BlankNodePropertyListContext):
        pass

    # Exit a parse tree produced by SparqlParser#blankNodePropertyList.
    def exitBlankNodePropertyList(self, ctx:SparqlParser.BlankNodePropertyListContext):
        pass


    # Enter a parse tree produced by SparqlParser#triplesNodePath.
    def enterTriplesNodePath(self, ctx:SparqlParser.TriplesNodePathContext):
        pass

    # Exit a parse tree produced by SparqlParser#triplesNodePath.
    def exitTriplesNodePath(self, ctx:SparqlParser.TriplesNodePathContext):
        pass


    # Enter a parse tree produced by SparqlParser#blankNodePropertyListPath.
    def enterBlankNodePropertyListPath(self, ctx:SparqlParser.BlankNodePropertyListPathContext):
        pass

    # Exit a parse tree produced by SparqlParser#blankNodePropertyListPath.
    def exitBlankNodePropertyListPath(self, ctx:SparqlParser.BlankNodePropertyListPathContext):
        pass


    # Enter a parse tree produced by SparqlParser#collection.
    def enterCollection(self, ctx:SparqlParser.CollectionContext):
        pass

    # Exit a parse tree produced by SparqlParser#collection.
    def exitCollection(self, ctx:SparqlParser.CollectionContext):
        pass


    # Enter a parse tree produced by SparqlParser#collectionPath.
    def enterCollectionPath(self, ctx:SparqlParser.CollectionPathContext):
        pass

    # Exit a parse tree produced by SparqlParser#collectionPath.
    def exitCollectionPath(self, ctx:SparqlParser.CollectionPathContext):
        pass


    # Enter a parse tree produced by SparqlParser#graphNode.
    def enterGraphNode(self, ctx:SparqlParser.GraphNodeContext):
        pass

    # Exit a parse tree produced by SparqlParser#graphNode.
    def exitGraphNode(self, ctx:SparqlParser.GraphNodeContext):
        pass


    # Enter a parse tree produced by SparqlParser#graphNodePath.
    def enterGraphNodePath(self, ctx:SparqlParser.GraphNodePathContext):
        pass

    # Exit a parse tree produced by SparqlParser#graphNodePath.
    def exitGraphNodePath(self, ctx:SparqlParser.GraphNodePathContext):
        pass


    # Enter a parse tree produced by SparqlParser#varOrTerm.
    def enterVarOrTerm(self, ctx:SparqlParser.VarOrTermContext):
        pass

    # Exit a parse tree produced by SparqlParser#varOrTerm.
    def exitVarOrTerm(self, ctx:SparqlParser.VarOrTermContext):
        pass


    # Enter a parse tree produced by SparqlParser#varOrIRI.
    def enterVarOrIRI(self, ctx:SparqlParser.VarOrIRIContext):
        pass

    # Exit a parse tree produced by SparqlParser#varOrIRI.
    def exitVarOrIRI(self, ctx:SparqlParser.VarOrIRIContext):
        pass


    # Enter a parse tree produced by SparqlParser#var.
    def enterVar(self, ctx:SparqlParser.VarContext):
        pass

    # Exit a parse tree produced by SparqlParser#var.
    def exitVar(self, ctx:SparqlParser.VarContext):
        pass


    # Enter a parse tree produced by SparqlParser#graphTerm.
    def enterGraphTerm(self, ctx:SparqlParser.GraphTermContext):
        pass

    # Exit a parse tree produced by SparqlParser#graphTerm.
    def exitGraphTerm(self, ctx:SparqlParser.GraphTermContext):
        pass


    # Enter a parse tree produced by SparqlParser#nil.
    def enterNil(self, ctx:SparqlParser.NilContext):
        pass

    # Exit a parse tree produced by SparqlParser#nil.
    def exitNil(self, ctx:SparqlParser.NilContext):
        pass


    # Enter a parse tree produced by SparqlParser#unarySignedLiteralExpression.
    def enterUnarySignedLiteralExpression(self, ctx:SparqlParser.UnarySignedLiteralExpressionContext):
        pass

    # Exit a parse tree produced by SparqlParser#unarySignedLiteralExpression.
    def exitUnarySignedLiteralExpression(self, ctx:SparqlParser.UnarySignedLiteralExpressionContext):
        pass


    # Enter a parse tree produced by SparqlParser#conditionalOrExpression.
    def enterConditionalOrExpression(self, ctx:SparqlParser.ConditionalOrExpressionContext):
        pass

    # Exit a parse tree produced by SparqlParser#conditionalOrExpression.
    def exitConditionalOrExpression(self, ctx:SparqlParser.ConditionalOrExpressionContext):
        pass


    # Enter a parse tree produced by SparqlParser#additiveExpression.
    def enterAdditiveExpression(self, ctx:SparqlParser.AdditiveExpressionContext):
        pass

    # Exit a parse tree produced by SparqlParser#additiveExpression.
    def exitAdditiveExpression(self, ctx:SparqlParser.AdditiveExpressionContext):
        pass


    # Enter a parse tree produced by SparqlParser#unaryAdditiveExpression.
    def enterUnaryAdditiveExpression(self, ctx:SparqlParser.UnaryAdditiveExpressionContext):
        pass

    # Exit a parse tree produced by SparqlParser#unaryAdditiveExpression.
    def exitUnaryAdditiveExpression(self, ctx:SparqlParser.UnaryAdditiveExpressionContext):
        pass


    # Enter a parse tree produced by SparqlParser#relationalExpression.
    def enterRelationalExpression(self, ctx:SparqlParser.RelationalExpressionContext):
        pass

    # Exit a parse tree produced by SparqlParser#relationalExpression.
    def exitRelationalExpression(self, ctx:SparqlParser.RelationalExpressionContext):
        pass


    # Enter a parse tree produced by SparqlParser#relationalSetExpression.
    def enterRelationalSetExpression(self, ctx:SparqlParser.RelationalSetExpressionContext):
        pass

    # Exit a parse tree produced by SparqlParser#relationalSetExpression.
    def exitRelationalSetExpression(self, ctx:SparqlParser.RelationalSetExpressionContext):
        pass


    # Enter a parse tree produced by SparqlParser#unaryMultiplicativeExpression.
    def enterUnaryMultiplicativeExpression(self, ctx:SparqlParser.UnaryMultiplicativeExpressionContext):
        pass

    # Exit a parse tree produced by SparqlParser#unaryMultiplicativeExpression.
    def exitUnaryMultiplicativeExpression(self, ctx:SparqlParser.UnaryMultiplicativeExpressionContext):
        pass


    # Enter a parse tree produced by SparqlParser#baseExpression.
    def enterBaseExpression(self, ctx:SparqlParser.BaseExpressionContext):
        pass

    # Exit a parse tree produced by SparqlParser#baseExpression.
    def exitBaseExpression(self, ctx:SparqlParser.BaseExpressionContext):
        pass


    # Enter a parse tree produced by SparqlParser#multiplicativeExpression.
    def enterMultiplicativeExpression(self, ctx:SparqlParser.MultiplicativeExpressionContext):
        pass

    # Exit a parse tree produced by SparqlParser#multiplicativeExpression.
    def exitMultiplicativeExpression(self, ctx:SparqlParser.MultiplicativeExpressionContext):
        pass


    # Enter a parse tree produced by SparqlParser#conditionalAndExpression.
    def enterConditionalAndExpression(self, ctx:SparqlParser.ConditionalAndExpressionContext):
        pass

    # Exit a parse tree produced by SparqlParser#conditionalAndExpression.
    def exitConditionalAndExpression(self, ctx:SparqlParser.ConditionalAndExpressionContext):
        pass


    # Enter a parse tree produced by SparqlParser#unaryNegationExpression.
    def enterUnaryNegationExpression(self, ctx:SparqlParser.UnaryNegationExpressionContext):
        pass

    # Exit a parse tree produced by SparqlParser#unaryNegationExpression.
    def exitUnaryNegationExpression(self, ctx:SparqlParser.UnaryNegationExpressionContext):
        pass


    # Enter a parse tree produced by SparqlParser#unaryLiteralExpression.
    def enterUnaryLiteralExpression(self, ctx:SparqlParser.UnaryLiteralExpressionContext):
        pass

    # Exit a parse tree produced by SparqlParser#unaryLiteralExpression.
    def exitUnaryLiteralExpression(self, ctx:SparqlParser.UnaryLiteralExpressionContext):
        pass


    # Enter a parse tree produced by SparqlParser#unaryExpression.
    def enterUnaryExpression(self, ctx:SparqlParser.UnaryExpressionContext):
        pass

    # Exit a parse tree produced by SparqlParser#unaryExpression.
    def exitUnaryExpression(self, ctx:SparqlParser.UnaryExpressionContext):
        pass


    # Enter a parse tree produced by SparqlParser#primaryExpression.
    def enterPrimaryExpression(self, ctx:SparqlParser.PrimaryExpressionContext):
        pass

    # Exit a parse tree produced by SparqlParser#primaryExpression.
    def exitPrimaryExpression(self, ctx:SparqlParser.PrimaryExpressionContext):
        pass


    # Enter a parse tree produced by SparqlParser#builtInCall.
    def enterBuiltInCall(self, ctx:SparqlParser.BuiltInCallContext):
        pass

    # Exit a parse tree produced by SparqlParser#builtInCall.
    def exitBuiltInCall(self, ctx:SparqlParser.BuiltInCallContext):
        pass


    # Enter a parse tree produced by SparqlParser#regexExpression.
    def enterRegexExpression(self, ctx:SparqlParser.RegexExpressionContext):
        pass

    # Exit a parse tree produced by SparqlParser#regexExpression.
    def exitRegexExpression(self, ctx:SparqlParser.RegexExpressionContext):
        pass


    # Enter a parse tree produced by SparqlParser#subStringExpression.
    def enterSubStringExpression(self, ctx:SparqlParser.SubStringExpressionContext):
        pass

    # Exit a parse tree produced by SparqlParser#subStringExpression.
    def exitSubStringExpression(self, ctx:SparqlParser.SubStringExpressionContext):
        pass


    # Enter a parse tree produced by SparqlParser#strReplaceExpression.
    def enterStrReplaceExpression(self, ctx:SparqlParser.StrReplaceExpressionContext):
        pass

    # Exit a parse tree produced by SparqlParser#strReplaceExpression.
    def exitStrReplaceExpression(self, ctx:SparqlParser.StrReplaceExpressionContext):
        pass


    # Enter a parse tree produced by SparqlParser#existsFunction.
    def enterExistsFunction(self, ctx:SparqlParser.ExistsFunctionContext):
        pass

    # Exit a parse tree produced by SparqlParser#existsFunction.
    def exitExistsFunction(self, ctx:SparqlParser.ExistsFunctionContext):
        pass


    # Enter a parse tree produced by SparqlParser#notExistsFunction.
    def enterNotExistsFunction(self, ctx:SparqlParser.NotExistsFunctionContext):
        pass

    # Exit a parse tree produced by SparqlParser#notExistsFunction.
    def exitNotExistsFunction(self, ctx:SparqlParser.NotExistsFunctionContext):
        pass


    # Enter a parse tree produced by SparqlParser#aggregate.
    def enterAggregate(self, ctx:SparqlParser.AggregateContext):
        pass

    # Exit a parse tree produced by SparqlParser#aggregate.
    def exitAggregate(self, ctx:SparqlParser.AggregateContext):
        pass


    # Enter a parse tree produced by SparqlParser#iriRefOrFunction.
    def enterIriRefOrFunction(self, ctx:SparqlParser.IriRefOrFunctionContext):
        pass

    # Exit a parse tree produced by SparqlParser#iriRefOrFunction.
    def exitIriRefOrFunction(self, ctx:SparqlParser.IriRefOrFunctionContext):
        pass


    # Enter a parse tree produced by SparqlParser#rdfLiteral.
    def enterRdfLiteral(self, ctx:SparqlParser.RdfLiteralContext):
        pass

    # Exit a parse tree produced by SparqlParser#rdfLiteral.
    def exitRdfLiteral(self, ctx:SparqlParser.RdfLiteralContext):
        pass


    # Enter a parse tree produced by SparqlParser#numericLiteral.
    def enterNumericLiteral(self, ctx:SparqlParser.NumericLiteralContext):
        pass

    # Exit a parse tree produced by SparqlParser#numericLiteral.
    def exitNumericLiteral(self, ctx:SparqlParser.NumericLiteralContext):
        pass


    # Enter a parse tree produced by SparqlParser#numericLiteralUnsigned.
    def enterNumericLiteralUnsigned(self, ctx:SparqlParser.NumericLiteralUnsignedContext):
        pass

    # Exit a parse tree produced by SparqlParser#numericLiteralUnsigned.
    def exitNumericLiteralUnsigned(self, ctx:SparqlParser.NumericLiteralUnsignedContext):
        pass


    # Enter a parse tree produced by SparqlParser#numericLiteralPositive.
    def enterNumericLiteralPositive(self, ctx:SparqlParser.NumericLiteralPositiveContext):
        pass

    # Exit a parse tree produced by SparqlParser#numericLiteralPositive.
    def exitNumericLiteralPositive(self, ctx:SparqlParser.NumericLiteralPositiveContext):
        pass


    # Enter a parse tree produced by SparqlParser#numericLiteralNegative.
    def enterNumericLiteralNegative(self, ctx:SparqlParser.NumericLiteralNegativeContext):
        pass

    # Exit a parse tree produced by SparqlParser#numericLiteralNegative.
    def exitNumericLiteralNegative(self, ctx:SparqlParser.NumericLiteralNegativeContext):
        pass


    # Enter a parse tree produced by SparqlParser#booleanLiteral.
    def enterBooleanLiteral(self, ctx:SparqlParser.BooleanLiteralContext):
        pass

    # Exit a parse tree produced by SparqlParser#booleanLiteral.
    def exitBooleanLiteral(self, ctx:SparqlParser.BooleanLiteralContext):
        pass


    # Enter a parse tree produced by SparqlParser#string.
    def enterString(self, ctx:SparqlParser.StringContext):
        pass

    # Exit a parse tree produced by SparqlParser#string.
    def exitString(self, ctx:SparqlParser.StringContext):
        pass


    # Enter a parse tree produced by SparqlParser#iri.
    def enterIri(self, ctx:SparqlParser.IriContext):
        pass

    # Exit a parse tree produced by SparqlParser#iri.
    def exitIri(self, ctx:SparqlParser.IriContext):
        pass


    # Enter a parse tree produced by SparqlParser#prefixedName.
    def enterPrefixedName(self, ctx:SparqlParser.PrefixedNameContext):
        pass

    # Exit a parse tree produced by SparqlParser#prefixedName.
    def exitPrefixedName(self, ctx:SparqlParser.PrefixedNameContext):
        pass


    # Enter a parse tree produced by SparqlParser#blankNode.
    def enterBlankNode(self, ctx:SparqlParser.BlankNodeContext):
        pass

    # Exit a parse tree produced by SparqlParser#blankNode.
    def exitBlankNode(self, ctx:SparqlParser.BlankNodeContext):
        pass


    # Enter a parse tree produced by SparqlParser#anon.
    def enterAnon(self, ctx:SparqlParser.AnonContext):
        pass

    # Exit a parse tree produced by SparqlParser#anon.
    def exitAnon(self, ctx:SparqlParser.AnonContext):
        pass



del SparqlParser




def get_grouped_params(self):
    no_decay = ["bias", "LayerNorm.weight"]

    # Group parameters to those that will and will not have weight decay applied
    optimizer_grouped_parameters = [
        {
            "params": [p for n, p in self.model.named_parameters() if not any(nd in n for nd in no_decay)],
            "weight_decay": 0.01,
        },
        {
            "params": [p for n, p in self.model.named_parameters() if any(nd in n for nd in no_decay)],
            "weight_decay": 0.0,
        },
    ]
    return optimizer_grouped_parameters

def get_finetune_param_groups(self):
    no_decay = ["bias", "LayerNorm.weight"]
    backbone_no_decay = {
        'params': [ p for n,p in self.model.named_parameters() if n.startswith("encoder") and any(nd in n for nd in no_decay) ],
        'weight_decay' : 0.0,
        'lr': 1e-5
    }
    backbone = {
        'params': [ p for n,p in self.model.named_parameters() if n.startswith("encoder") and not any(nd in n for nd in no_decay) ],
        'weight_decay' : 0.01,
        'lr': 1e-5
    }
    new_initialized = {
        'params': [ p for n,p in self.model.named_parameters() if not n.startswith("encoder") ],
        'lr': 3e-5
    }
    return [backbone_no_decay, backbone, new_initialized]





# Generated from ./Cypher.g4 by ANTLR 4.9.3
from antlr4 import *
if __name__ is not None and "." in __name__:
    from .CypherParser import CypherParser
else:
    from CypherParser import CypherParser

# This class defines a complete listener for a parse tree produced by CypherParser.
class CypherListener(ParseTreeListener):

    # Enter a parse tree produced by CypherParser#oC_Cypher.
    def enterOC_Cypher(self, ctx:CypherParser.OC_CypherContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_Cypher.
    def exitOC_Cypher(self, ctx:CypherParser.OC_CypherContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_Statement.
    def enterOC_Statement(self, ctx:CypherParser.OC_StatementContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_Statement.
    def exitOC_Statement(self, ctx:CypherParser.OC_StatementContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_Query.
    def enterOC_Query(self, ctx:CypherParser.OC_QueryContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_Query.
    def exitOC_Query(self, ctx:CypherParser.OC_QueryContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_CallSubQuery.
    def enterOC_CallSubQuery(self, ctx:CypherParser.OC_CallSubQueryContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_CallSubQuery.
    def exitOC_CallSubQuery(self, ctx:CypherParser.OC_CallSubQueryContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_RegularQuery.
    def enterOC_RegularQuery(self, ctx:CypherParser.OC_RegularQueryContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_RegularQuery.
    def exitOC_RegularQuery(self, ctx:CypherParser.OC_RegularQueryContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_Union.
    def enterOC_Union(self, ctx:CypherParser.OC_UnionContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_Union.
    def exitOC_Union(self, ctx:CypherParser.OC_UnionContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_SingleQuery.
    def enterOC_SingleQuery(self, ctx:CypherParser.OC_SingleQueryContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_SingleQuery.
    def exitOC_SingleQuery(self, ctx:CypherParser.OC_SingleQueryContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_SinglePartQuery.
    def enterOC_SinglePartQuery(self, ctx:CypherParser.OC_SinglePartQueryContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_SinglePartQuery.
    def exitOC_SinglePartQuery(self, ctx:CypherParser.OC_SinglePartQueryContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_MultiPartQuery.
    def enterOC_MultiPartQuery(self, ctx:CypherParser.OC_MultiPartQueryContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_MultiPartQuery.
    def exitOC_MultiPartQuery(self, ctx:CypherParser.OC_MultiPartQueryContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_UpdatingClause.
    def enterOC_UpdatingClause(self, ctx:CypherParser.OC_UpdatingClauseContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_UpdatingClause.
    def exitOC_UpdatingClause(self, ctx:CypherParser.OC_UpdatingClauseContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_ReadingClause.
    def enterOC_ReadingClause(self, ctx:CypherParser.OC_ReadingClauseContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_ReadingClause.
    def exitOC_ReadingClause(self, ctx:CypherParser.OC_ReadingClauseContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_Match.
    def enterOC_Match(self, ctx:CypherParser.OC_MatchContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_Match.
    def exitOC_Match(self, ctx:CypherParser.OC_MatchContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_Unwind.
    def enterOC_Unwind(self, ctx:CypherParser.OC_UnwindContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_Unwind.
    def exitOC_Unwind(self, ctx:CypherParser.OC_UnwindContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_Merge.
    def enterOC_Merge(self, ctx:CypherParser.OC_MergeContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_Merge.
    def exitOC_Merge(self, ctx:CypherParser.OC_MergeContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_MergeAction.
    def enterOC_MergeAction(self, ctx:CypherParser.OC_MergeActionContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_MergeAction.
    def exitOC_MergeAction(self, ctx:CypherParser.OC_MergeActionContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_Create.
    def enterOC_Create(self, ctx:CypherParser.OC_CreateContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_Create.
    def exitOC_Create(self, ctx:CypherParser.OC_CreateContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_Set.
    def enterOC_Set(self, ctx:CypherParser.OC_SetContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_Set.
    def exitOC_Set(self, ctx:CypherParser.OC_SetContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_SetItem.
    def enterOC_SetItem(self, ctx:CypherParser.OC_SetItemContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_SetItem.
    def exitOC_SetItem(self, ctx:CypherParser.OC_SetItemContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_Delete.
    def enterOC_Delete(self, ctx:CypherParser.OC_DeleteContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_Delete.
    def exitOC_Delete(self, ctx:CypherParser.OC_DeleteContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_Remove.
    def enterOC_Remove(self, ctx:CypherParser.OC_RemoveContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_Remove.
    def exitOC_Remove(self, ctx:CypherParser.OC_RemoveContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_RemoveItem.
    def enterOC_RemoveItem(self, ctx:CypherParser.OC_RemoveItemContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_RemoveItem.
    def exitOC_RemoveItem(self, ctx:CypherParser.OC_RemoveItemContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_InQueryCall.
    def enterOC_InQueryCall(self, ctx:CypherParser.OC_InQueryCallContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_InQueryCall.
    def exitOC_InQueryCall(self, ctx:CypherParser.OC_InQueryCallContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_StandaloneCall.
    def enterOC_StandaloneCall(self, ctx:CypherParser.OC_StandaloneCallContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_StandaloneCall.
    def exitOC_StandaloneCall(self, ctx:CypherParser.OC_StandaloneCallContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_YieldItems.
    def enterOC_YieldItems(self, ctx:CypherParser.OC_YieldItemsContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_YieldItems.
    def exitOC_YieldItems(self, ctx:CypherParser.OC_YieldItemsContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_YieldItem.
    def enterOC_YieldItem(self, ctx:CypherParser.OC_YieldItemContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_YieldItem.
    def exitOC_YieldItem(self, ctx:CypherParser.OC_YieldItemContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_With.
    def enterOC_With(self, ctx:CypherParser.OC_WithContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_With.
    def exitOC_With(self, ctx:CypherParser.OC_WithContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_Return.
    def enterOC_Return(self, ctx:CypherParser.OC_ReturnContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_Return.
    def exitOC_Return(self, ctx:CypherParser.OC_ReturnContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_ProjectionBody.
    def enterOC_ProjectionBody(self, ctx:CypherParser.OC_ProjectionBodyContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_ProjectionBody.
    def exitOC_ProjectionBody(self, ctx:CypherParser.OC_ProjectionBodyContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_ProjectionItems.
    def enterOC_ProjectionItems(self, ctx:CypherParser.OC_ProjectionItemsContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_ProjectionItems.
    def exitOC_ProjectionItems(self, ctx:CypherParser.OC_ProjectionItemsContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_ProjectionItem.
    def enterOC_ProjectionItem(self, ctx:CypherParser.OC_ProjectionItemContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_ProjectionItem.
    def exitOC_ProjectionItem(self, ctx:CypherParser.OC_ProjectionItemContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_Order.
    def enterOC_Order(self, ctx:CypherParser.OC_OrderContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_Order.
    def exitOC_Order(self, ctx:CypherParser.OC_OrderContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_Skip.
    def enterOC_Skip(self, ctx:CypherParser.OC_SkipContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_Skip.
    def exitOC_Skip(self, ctx:CypherParser.OC_SkipContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_Limit.
    def enterOC_Limit(self, ctx:CypherParser.OC_LimitContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_Limit.
    def exitOC_Limit(self, ctx:CypherParser.OC_LimitContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_SortItem.
    def enterOC_SortItem(self, ctx:CypherParser.OC_SortItemContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_SortItem.
    def exitOC_SortItem(self, ctx:CypherParser.OC_SortItemContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_Where.
    def enterOC_Where(self, ctx:CypherParser.OC_WhereContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_Where.
    def exitOC_Where(self, ctx:CypherParser.OC_WhereContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_Pattern.
    def enterOC_Pattern(self, ctx:CypherParser.OC_PatternContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_Pattern.
    def exitOC_Pattern(self, ctx:CypherParser.OC_PatternContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_PatternPart.
    def enterOC_PatternPart(self, ctx:CypherParser.OC_PatternPartContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_PatternPart.
    def exitOC_PatternPart(self, ctx:CypherParser.OC_PatternPartContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_AnonymousPatternPart.
    def enterOC_AnonymousPatternPart(self, ctx:CypherParser.OC_AnonymousPatternPartContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_AnonymousPatternPart.
    def exitOC_AnonymousPatternPart(self, ctx:CypherParser.OC_AnonymousPatternPartContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_PatternElement.
    def enterOC_PatternElement(self, ctx:CypherParser.OC_PatternElementContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_PatternElement.
    def exitOC_PatternElement(self, ctx:CypherParser.OC_PatternElementContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_RelationshipsPattern.
    def enterOC_RelationshipsPattern(self, ctx:CypherParser.OC_RelationshipsPatternContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_RelationshipsPattern.
    def exitOC_RelationshipsPattern(self, ctx:CypherParser.OC_RelationshipsPatternContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_NodePattern.
    def enterOC_NodePattern(self, ctx:CypherParser.OC_NodePatternContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_NodePattern.
    def exitOC_NodePattern(self, ctx:CypherParser.OC_NodePatternContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_PatternElementChain.
    def enterOC_PatternElementChain(self, ctx:CypherParser.OC_PatternElementChainContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_PatternElementChain.
    def exitOC_PatternElementChain(self, ctx:CypherParser.OC_PatternElementChainContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_RelationshipPattern.
    def enterOC_RelationshipPattern(self, ctx:CypherParser.OC_RelationshipPatternContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_RelationshipPattern.
    def exitOC_RelationshipPattern(self, ctx:CypherParser.OC_RelationshipPatternContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_RelationshipDetail.
    def enterOC_RelationshipDetail(self, ctx:CypherParser.OC_RelationshipDetailContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_RelationshipDetail.
    def exitOC_RelationshipDetail(self, ctx:CypherParser.OC_RelationshipDetailContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_Properties.
    def enterOC_Properties(self, ctx:CypherParser.OC_PropertiesContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_Properties.
    def exitOC_Properties(self, ctx:CypherParser.OC_PropertiesContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_RelationshipTypes.
    def enterOC_RelationshipTypes(self, ctx:CypherParser.OC_RelationshipTypesContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_RelationshipTypes.
    def exitOC_RelationshipTypes(self, ctx:CypherParser.OC_RelationshipTypesContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_NodeLabels.
    def enterOC_NodeLabels(self, ctx:CypherParser.OC_NodeLabelsContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_NodeLabels.
    def exitOC_NodeLabels(self, ctx:CypherParser.OC_NodeLabelsContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_NodeLabel.
    def enterOC_NodeLabel(self, ctx:CypherParser.OC_NodeLabelContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_NodeLabel.
    def exitOC_NodeLabel(self, ctx:CypherParser.OC_NodeLabelContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_RangeLiteral.
    def enterOC_RangeLiteral(self, ctx:CypherParser.OC_RangeLiteralContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_RangeLiteral.
    def exitOC_RangeLiteral(self, ctx:CypherParser.OC_RangeLiteralContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_LabelName.
    def enterOC_LabelName(self, ctx:CypherParser.OC_LabelNameContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_LabelName.
    def exitOC_LabelName(self, ctx:CypherParser.OC_LabelNameContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_RelTypeName.
    def enterOC_RelTypeName(self, ctx:CypherParser.OC_RelTypeNameContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_RelTypeName.
    def exitOC_RelTypeName(self, ctx:CypherParser.OC_RelTypeNameContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_PropertyExpression.
    def enterOC_PropertyExpression(self, ctx:CypherParser.OC_PropertyExpressionContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_PropertyExpression.
    def exitOC_PropertyExpression(self, ctx:CypherParser.OC_PropertyExpressionContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_Expression.
    def enterOC_Expression(self, ctx:CypherParser.OC_ExpressionContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_Expression.
    def exitOC_Expression(self, ctx:CypherParser.OC_ExpressionContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_OrExpression.
    def enterOC_OrExpression(self, ctx:CypherParser.OC_OrExpressionContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_OrExpression.
    def exitOC_OrExpression(self, ctx:CypherParser.OC_OrExpressionContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_XorExpression.
    def enterOC_XorExpression(self, ctx:CypherParser.OC_XorExpressionContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_XorExpression.
    def exitOC_XorExpression(self, ctx:CypherParser.OC_XorExpressionContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_AndExpression.
    def enterOC_AndExpression(self, ctx:CypherParser.OC_AndExpressionContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_AndExpression.
    def exitOC_AndExpression(self, ctx:CypherParser.OC_AndExpressionContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_NotExpression.
    def enterOC_NotExpression(self, ctx:CypherParser.OC_NotExpressionContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_NotExpression.
    def exitOC_NotExpression(self, ctx:CypherParser.OC_NotExpressionContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_ComparisonExpression.
    def enterOC_ComparisonExpression(self, ctx:CypherParser.OC_ComparisonExpressionContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_ComparisonExpression.
    def exitOC_ComparisonExpression(self, ctx:CypherParser.OC_ComparisonExpressionContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_PartialComparisonExpression.
    def enterOC_PartialComparisonExpression(self, ctx:CypherParser.OC_PartialComparisonExpressionContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_PartialComparisonExpression.
    def exitOC_PartialComparisonExpression(self, ctx:CypherParser.OC_PartialComparisonExpressionContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_StringListNullPredicateExpression.
    def enterOC_StringListNullPredicateExpression(self, ctx:CypherParser.OC_StringListNullPredicateExpressionContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_StringListNullPredicateExpression.
    def exitOC_StringListNullPredicateExpression(self, ctx:CypherParser.OC_StringListNullPredicateExpressionContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_StringPredicateExpression.
    def enterOC_StringPredicateExpression(self, ctx:CypherParser.OC_StringPredicateExpressionContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_StringPredicateExpression.
    def exitOC_StringPredicateExpression(self, ctx:CypherParser.OC_StringPredicateExpressionContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_ListPredicateExpression.
    def enterOC_ListPredicateExpression(self, ctx:CypherParser.OC_ListPredicateExpressionContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_ListPredicateExpression.
    def exitOC_ListPredicateExpression(self, ctx:CypherParser.OC_ListPredicateExpressionContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_NullPredicateExpression.
    def enterOC_NullPredicateExpression(self, ctx:CypherParser.OC_NullPredicateExpressionContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_NullPredicateExpression.
    def exitOC_NullPredicateExpression(self, ctx:CypherParser.OC_NullPredicateExpressionContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_AddOrSubtractExpression.
    def enterOC_AddOrSubtractExpression(self, ctx:CypherParser.OC_AddOrSubtractExpressionContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_AddOrSubtractExpression.
    def exitOC_AddOrSubtractExpression(self, ctx:CypherParser.OC_AddOrSubtractExpressionContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_MultiplyDivideModuloExpression.
    def enterOC_MultiplyDivideModuloExpression(self, ctx:CypherParser.OC_MultiplyDivideModuloExpressionContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_MultiplyDivideModuloExpression.
    def exitOC_MultiplyDivideModuloExpression(self, ctx:CypherParser.OC_MultiplyDivideModuloExpressionContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_PowerOfExpression.
    def enterOC_PowerOfExpression(self, ctx:CypherParser.OC_PowerOfExpressionContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_PowerOfExpression.
    def exitOC_PowerOfExpression(self, ctx:CypherParser.OC_PowerOfExpressionContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_UnaryAddOrSubtractExpression.
    def enterOC_UnaryAddOrSubtractExpression(self, ctx:CypherParser.OC_UnaryAddOrSubtractExpressionContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_UnaryAddOrSubtractExpression.
    def exitOC_UnaryAddOrSubtractExpression(self, ctx:CypherParser.OC_UnaryAddOrSubtractExpressionContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_ListOperatorExpression.
    def enterOC_ListOperatorExpression(self, ctx:CypherParser.OC_ListOperatorExpressionContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_ListOperatorExpression.
    def exitOC_ListOperatorExpression(self, ctx:CypherParser.OC_ListOperatorExpressionContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_PropertyOrLabelsExpression.
    def enterOC_PropertyOrLabelsExpression(self, ctx:CypherParser.OC_PropertyOrLabelsExpressionContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_PropertyOrLabelsExpression.
    def exitOC_PropertyOrLabelsExpression(self, ctx:CypherParser.OC_PropertyOrLabelsExpressionContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_PropertyLookup.
    def enterOC_PropertyLookup(self, ctx:CypherParser.OC_PropertyLookupContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_PropertyLookup.
    def exitOC_PropertyLookup(self, ctx:CypherParser.OC_PropertyLookupContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_Atom.
    def enterOC_Atom(self, ctx:CypherParser.OC_AtomContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_Atom.
    def exitOC_Atom(self, ctx:CypherParser.OC_AtomContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_CaseExpression.
    def enterOC_CaseExpression(self, ctx:CypherParser.OC_CaseExpressionContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_CaseExpression.
    def exitOC_CaseExpression(self, ctx:CypherParser.OC_CaseExpressionContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_CaseAlternative.
    def enterOC_CaseAlternative(self, ctx:CypherParser.OC_CaseAlternativeContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_CaseAlternative.
    def exitOC_CaseAlternative(self, ctx:CypherParser.OC_CaseAlternativeContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_ListComprehension.
    def enterOC_ListComprehension(self, ctx:CypherParser.OC_ListComprehensionContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_ListComprehension.
    def exitOC_ListComprehension(self, ctx:CypherParser.OC_ListComprehensionContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_PatternComprehension.
    def enterOC_PatternComprehension(self, ctx:CypherParser.OC_PatternComprehensionContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_PatternComprehension.
    def exitOC_PatternComprehension(self, ctx:CypherParser.OC_PatternComprehensionContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_Quantifier.
    def enterOC_Quantifier(self, ctx:CypherParser.OC_QuantifierContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_Quantifier.
    def exitOC_Quantifier(self, ctx:CypherParser.OC_QuantifierContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_FilterExpression.
    def enterOC_FilterExpression(self, ctx:CypherParser.OC_FilterExpressionContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_FilterExpression.
    def exitOC_FilterExpression(self, ctx:CypherParser.OC_FilterExpressionContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_PatternPredicate.
    def enterOC_PatternPredicate(self, ctx:CypherParser.OC_PatternPredicateContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_PatternPredicate.
    def exitOC_PatternPredicate(self, ctx:CypherParser.OC_PatternPredicateContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_ParenthesizedExpression.
    def enterOC_ParenthesizedExpression(self, ctx:CypherParser.OC_ParenthesizedExpressionContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_ParenthesizedExpression.
    def exitOC_ParenthesizedExpression(self, ctx:CypherParser.OC_ParenthesizedExpressionContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_IdInColl.
    def enterOC_IdInColl(self, ctx:CypherParser.OC_IdInCollContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_IdInColl.
    def exitOC_IdInColl(self, ctx:CypherParser.OC_IdInCollContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_FunctionInvocation.
    def enterOC_FunctionInvocation(self, ctx:CypherParser.OC_FunctionInvocationContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_FunctionInvocation.
    def exitOC_FunctionInvocation(self, ctx:CypherParser.OC_FunctionInvocationContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_FunctionName.
    def enterOC_FunctionName(self, ctx:CypherParser.OC_FunctionNameContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_FunctionName.
    def exitOC_FunctionName(self, ctx:CypherParser.OC_FunctionNameContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_ExistentialSubquery.
    def enterOC_ExistentialSubquery(self, ctx:CypherParser.OC_ExistentialSubqueryContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_ExistentialSubquery.
    def exitOC_ExistentialSubquery(self, ctx:CypherParser.OC_ExistentialSubqueryContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_ExplicitProcedureInvocation.
    def enterOC_ExplicitProcedureInvocation(self, ctx:CypherParser.OC_ExplicitProcedureInvocationContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_ExplicitProcedureInvocation.
    def exitOC_ExplicitProcedureInvocation(self, ctx:CypherParser.OC_ExplicitProcedureInvocationContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_ImplicitProcedureInvocation.
    def enterOC_ImplicitProcedureInvocation(self, ctx:CypherParser.OC_ImplicitProcedureInvocationContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_ImplicitProcedureInvocation.
    def exitOC_ImplicitProcedureInvocation(self, ctx:CypherParser.OC_ImplicitProcedureInvocationContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_ProcedureResultField.
    def enterOC_ProcedureResultField(self, ctx:CypherParser.OC_ProcedureResultFieldContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_ProcedureResultField.
    def exitOC_ProcedureResultField(self, ctx:CypherParser.OC_ProcedureResultFieldContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_ProcedureName.
    def enterOC_ProcedureName(self, ctx:CypherParser.OC_ProcedureNameContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_ProcedureName.
    def exitOC_ProcedureName(self, ctx:CypherParser.OC_ProcedureNameContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_Namespace.
    def enterOC_Namespace(self, ctx:CypherParser.OC_NamespaceContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_Namespace.
    def exitOC_Namespace(self, ctx:CypherParser.OC_NamespaceContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_Variable.
    def enterOC_Variable(self, ctx:CypherParser.OC_VariableContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_Variable.
    def exitOC_Variable(self, ctx:CypherParser.OC_VariableContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_Literal.
    def enterOC_Literal(self, ctx:CypherParser.OC_LiteralContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_Literal.
    def exitOC_Literal(self, ctx:CypherParser.OC_LiteralContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_BooleanLiteral.
    def enterOC_BooleanLiteral(self, ctx:CypherParser.OC_BooleanLiteralContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_BooleanLiteral.
    def exitOC_BooleanLiteral(self, ctx:CypherParser.OC_BooleanLiteralContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_NumberLiteral.
    def enterOC_NumberLiteral(self, ctx:CypherParser.OC_NumberLiteralContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_NumberLiteral.
    def exitOC_NumberLiteral(self, ctx:CypherParser.OC_NumberLiteralContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_IntegerLiteral.
    def enterOC_IntegerLiteral(self, ctx:CypherParser.OC_IntegerLiteralContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_IntegerLiteral.
    def exitOC_IntegerLiteral(self, ctx:CypherParser.OC_IntegerLiteralContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_DoubleLiteral.
    def enterOC_DoubleLiteral(self, ctx:CypherParser.OC_DoubleLiteralContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_DoubleLiteral.
    def exitOC_DoubleLiteral(self, ctx:CypherParser.OC_DoubleLiteralContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_ListLiteral.
    def enterOC_ListLiteral(self, ctx:CypherParser.OC_ListLiteralContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_ListLiteral.
    def exitOC_ListLiteral(self, ctx:CypherParser.OC_ListLiteralContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_MapLiteral.
    def enterOC_MapLiteral(self, ctx:CypherParser.OC_MapLiteralContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_MapLiteral.
    def exitOC_MapLiteral(self, ctx:CypherParser.OC_MapLiteralContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_PropertyKeyName.
    def enterOC_PropertyKeyName(self, ctx:CypherParser.OC_PropertyKeyNameContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_PropertyKeyName.
    def exitOC_PropertyKeyName(self, ctx:CypherParser.OC_PropertyKeyNameContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_Parameter.
    def enterOC_Parameter(self, ctx:CypherParser.OC_ParameterContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_Parameter.
    def exitOC_Parameter(self, ctx:CypherParser.OC_ParameterContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_SchemaName.
    def enterOC_SchemaName(self, ctx:CypherParser.OC_SchemaNameContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_SchemaName.
    def exitOC_SchemaName(self, ctx:CypherParser.OC_SchemaNameContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_ReservedWord.
    def enterOC_ReservedWord(self, ctx:CypherParser.OC_ReservedWordContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_ReservedWord.
    def exitOC_ReservedWord(self, ctx:CypherParser.OC_ReservedWordContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_SymbolicName.
    def enterOC_SymbolicName(self, ctx:CypherParser.OC_SymbolicNameContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_SymbolicName.
    def exitOC_SymbolicName(self, ctx:CypherParser.OC_SymbolicNameContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_LeftArrowHead.
    def enterOC_LeftArrowHead(self, ctx:CypherParser.OC_LeftArrowHeadContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_LeftArrowHead.
    def exitOC_LeftArrowHead(self, ctx:CypherParser.OC_LeftArrowHeadContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_RightArrowHead.
    def enterOC_RightArrowHead(self, ctx:CypherParser.OC_RightArrowHeadContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_RightArrowHead.
    def exitOC_RightArrowHead(self, ctx:CypherParser.OC_RightArrowHeadContext):
        pass


    # Enter a parse tree produced by CypherParser#oC_Dash.
    def enterOC_Dash(self, ctx:CypherParser.OC_DashContext):
        pass

    # Exit a parse tree produced by CypherParser#oC_Dash.
    def exitOC_Dash(self, ctx:CypherParser.OC_DashContext):
        pass



del CypherParser